import { ErrorHandler, NgModule } from '@angular/core';

import { AppComponent } from './app.component';
import { HomeComponent } from './home/home.component';
import { RegisterComponent } from './register/register.component';

import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { AppRoutingModule } from '@app/app-routing.module';
import { AngularFireModule } from '@angular/fire';
import { AngularFireDatabaseModule } from '@angular/fire/database';
import { AngularFireAuthModule } from '@angular/fire/auth';
import { AppMaterialModule } from '@app/app-material.module';

import { LogService, SEOService } from '@app/core/services';
import { GlobalErrorHandler } from '@app/core/global-error-handler/global-error-handler.service';

import { environment } from '@env/environment';
import { CardComponent } from './card/card.component';
import { SearchCardComponent } from './search-card/search-card.component';
import { ActivitiesComponent } from './activities/activities.component';
import {AngularFirestore} from '@angular/fire/firestore';
import { ScheduleComponent } from './schedule/schedule.component';
import {MatDialogModule} from '@angular/material';
import { NewScheduleComponent } from './new-schedule/new-schedule.component';

@NgModule( {
  declarations: [
    AppComponent,
    HomeComponent,
    RegisterComponent,
    CardComponent,
    SearchCardComponent,
    ActivitiesComponent,
    ScheduleComponent,
    NewScheduleComponent,
  ],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    AppRoutingModule,
    AngularFireModule.initializeApp( environment.firebaseConfig ),
    AngularFireAuthModule,
    AngularFireDatabaseModule,
    AppMaterialModule,
    MatDialogModule,
  ],
  providers: [
    AngularFirestore,
    LogService,
    SEOService,
    {
      provide: ErrorHandler,
      useClass: GlobalErrorHandler,
    },
  ],
  bootstrap: [ AppComponent ],
  entryComponents: [NewScheduleComponent],
} )
export class AppModule {
}
