import { Injectable } from '@angular/core';

import { Storage } from '@app/core/model';

@Injectable()
export class StorageService {

  private data: Storage;

  constructor() {
    const localData = localStorage.getItem( 'c2a' );
    const sessionData = sessionStorage.getItem( 'c2a' );

    this.data = new Storage();
    this.data.pageData = {};
    this.data.sessionData = ( sessionData ? JSON.parse( sessionData ) : {} );
    this.data.localData = ( localData ? JSON.parse( localData ) : {} );
  }

  public getLocal( key: string ): string | number | boolean | object {
    const value = this.data.localData[ key ];

    if ( !value ) {
      return null;
    }
    return value;
  }

  public getSession( key: string ): string | number | boolean | object {
    const value = this.data.sessionData[ key ];

    if ( !value ) {
      return null;
    }
    return value;
  }

  public getPage( key: string ): string | number | boolean | object {
    const value = this.data.pageData[ key ];

    if ( !value ) {
      return null;
    }
    return value;
  }

  public setLocal( key: string, value?: any ): void {
    let val: string | number | boolean;

    if ( typeof value === 'boolean' || 'string' || 'number' || 'object' ) {
      val = value;
    } else {
      val = null;
    }

    if ( val === null ) {
      if ( this.data.localData[ key ] ) {
        delete this.data.localData[ key ];
      }
    } else {
      this.data.localData[ key ] = val;
    }
    localStorage.setItem( 'discoTrip', JSON.stringify( this.data.localData ) );
  }

  public setSession( key: string, value?: any ): void {
    let val: string | number | boolean;

    if ( typeof value === 'boolean' || 'string' || 'number' || 'object' ) {
      val = value;
    } else {
      val = null;
    }

    if ( val === null ) {
      if ( this.data.sessionData[ key ] ) {
        delete this.data.sessionData[ key ];
      }
    } else {
      this.data.sessionData[ key ] = val;
    }
    sessionStorage.setItem( 'discoTrip', JSON.stringify( this.data.localData ) );
  }

  public setPage( key: string, value?: any ): void {
    let val: string | number | boolean;

    if ( typeof value === 'boolean' || 'string' || 'number' || 'object' ) {
      val = value;
    } else {
      val = null;
    }

    if ( val === null ) {
      if ( this.data.pageData[ key ] ) {
        delete this.data.pageData[ key ];
      }
    } else {
      this.data.pageData[ key ] = val;
    }
  }

}
